@@ -20,7 +20,7 @@ from SCons.Environment import Environment
 has_pywin32 = False
 if platform.system() == "Windows":
     import importlib
-    has_pywin32 = importlib.util.find_spec("win32api") is not None
+    has_pywin32 = importlib.util.find_spec("win32api") is not None  # type: ignore
 
 
 in_stata = 'sfi' in sys.modules
@@ -193,7 +193,7 @@ def changed_timestamp_then_dependency_newer_then_content_content(dependency, tar
 
 decider_str_lookup = {'content-timestamp-newer': dependency_newer_then_content_changed,
                       'content-timestamp-newer-timestamp-changed': changed_timestamp_then_dependency_newer_then_content_content}  # noqa: E501
-decider_str_lookup.update({k: k for k in ['MD5', 'content', 'MD5-timestamp', 'content-timestamp', 'timestamp-newer',
+decider_str_lookup.update({k: k for k in ['MD5', 'content', 'MD5-timestamp', 'content-timestamp', 'timestamp-newer',  # type: ignore
                                           'make', 'timestamp-match']})
 
 
@@ -558,14 +558,13 @@ def hash_file_signature_new(fname, chunksize=65536, hash_format=None):
     fname_ext = os.path.splitext(fname)[1]
     if fname_ext in special_sig_fns.keys():
         try:
-            # print_during_build(str(fname_ext) + "\n")
             sig = special_sig_fns[fname_ext](fname)
-            print_during_build('Computed ' + fname_ext[1:] + '-signature: ' + fname + "\n")
+            if "explain" in GetOption("debug"):
+                print_during_build('Computed ' + fname_ext[1:] + '-signature: ' + fname + "\n")
             return sig
         except Exception as e:
-            print_during_build(str(e) + "\n")
-            # print_during_build(str(fname_ext) + "\n")
-            pass
+            print_during_build('Error when computing ' + fname_ext[1:] + '-signature: ' + fname + "\n")
+            raise e
 
     return SCons.Util.hash_file_signature(fname, chunksize, hash_format)
 
